@@ -1,4 +1,5 @@
 import os
+import json
 from numbers import Number
 from tqdm import tqdm
 
@@ -57,6 +58,7 @@ class FFmpegNormalize():
         subtitle_disable=False,
         metadata_disable=False,
         chapters_disable=False,
+        extra_input_options=None,
         extra_output_options=None,
         output_format=None,
         dry_run=False,
@@ -107,6 +109,7 @@ class FFmpegNormalize():
         self.metadata_disable = metadata_disable
         self.chapters_disable = chapters_disable
 
+        self.extra_input_options = extra_input_options
         self.extra_output_options = extra_output_options
         self.pre_filter = pre_filter
         self.post_filter = post_filter
@@ -116,6 +119,8 @@ class FFmpegNormalize():
         self.debug = debug
         self.progress = progress
 
+        self.stats = []
+
         if self.output_format and (self.audio_codec is None or 'pcm' in self.audio_codec) and \
             self.output_format in PCM_INCOMPATIBLE_FORMATS:
             raise FFmpegNormalizeError(
@@ -188,3 +193,6 @@ class FFmpegNormalize():
                     raise e
 
             logger.info("Normalized file written to {}".format(media_file.output_file))
+
+        if self.print_stats and self.stats:
+            print(json.dumps(self.stats, indent=4))
